/*******************************************************************************
* Copyright (C) 2019 China Micro Semiconductor Limited Company. All Rights Reserved.
*
* This software is owned and published by:
* CMS LLC, No 2609-10, Taurus Plaza, TaoyuanRoad, NanshanDistrict, Shenzhen, China.
*
* BY DOWNLOADING, INSTALLING OR USING THIS SOFTWARE, YOU AGREE TO BE BOUND
* BY ALL THE TERMS AND CONDITIONS OF THIS AGREEMENT.
*
* This software contains source code for use with CMS
* components. This software is licensed by CMS to be adapted only
* for use in systems utilizing CMS components. CMS shall not be
* responsible for misuse or illegal use of this software for devices not
* supported herein. CMS is providing this software "AS IS" and will
* not be responsible for issues arising from incorrect user implementation
* of the software.
*
* This software may be replicated in part or whole for the licensed use,
* with the restriction that this Disclaimer and Copyright notice must be
* included with each copy of this software, whether used in part or whole,
* at all times.
*/

/*****************************************************************************/
/** \file bsp_SigmaDelta_adc.h
**
** 
**
** History:
** 
******************************************************************************/
#ifndef __BSP_SIGMA_DELTA_ADC_H__
#define __BSP_SIGMA_DELTA_ADC_H__
/*****************************************************************************/
/* Include files */
/*****************************************************************************/
#include "bsp_config.h"

/*****************************************************************************/
/* Global pre-processor symbols/macros ('#define') */
/*****************************************************************************/

/*-----通信口--------------------------*/
#define  DOUT    P05				// DOUT脚连接
#define  SCK     P04				// SCK脚连接

#define ADC_SDA_INPUT_MODE()	(P0TRIS &=~(1<<5))
#define ADC_SDA_OUTPUT_MODE()	(P0TRIS |=(1<<5))


#define DOUT_IS_LOW			(0 == DOUT)
#define DOUT_IS_HIGH		(1 == DOUT)
#define DOUT_SET			(DOUT =1)
#define DOUT_CLR			(DOUT =0)

#define SCK_SET				(SCK = 1)
#define SCK_CLR				(SCK = 0)


//检测
#define  SCK_DELAY_US		 2		
#define ADC_CHECK_CNT		 10			//10次


//寄存器定义
/*------------------------------------------------------*/
/*------LDO设置-----------------------------------------*/
#define  CMS_SET_LDO_3V			(0x0)		
#define  CMS_SET_LDO_2P4V		(0x1)		
#define  CMS_SET_LDO_2P6V		(0x2)		
#define  CMS_SET_LDO_3P3V		(0x3)

#define  CMS_LDO_BYPASS_OFF		(0x0)		
#define  CMS_LDO_BYPASS_ON		(0x1)	//LDO作为开关管

#define  CMS_LDO_OUT_PROTECT_ON		(0x0)	
#define  CMS_LDO_OUT_PROTECT_OFF	(0x1)

/*------通道设置----------------------------------*/

#define  CMS_CH_SET_CH1			(0x0)	//通道1
#define  CMS_CH_SET_CH2			(0x1)	//通道2	

/*------通道相关功能设置----------------------------------*/
#define  CMS_CH_SEL_CH			(0x0)	//默认
#define  CMS_CH_SEL_CHOP		(0x1)	//正负交换(系统斩波)
#define  CMS_CH_SEL_TP			(0x2)	//温度
#define  CMS_CH_SEL_INSHORT		(0x3)	//内短
#define  CMS_CH_SEL_NO_PGA		(0x4)	//绕过PGA直接输入
#define  CMS_CH_SEL_BG			(0x6)   //内部BG
#define  CMS_CH_SEL_INSHORT_NO_PGA	(0x7)		//内短

/*------PGA放大倍数设置----------------------------------*/
#define  CMS_PGA_SEL_2		(0x0)		
#define  CMS_PGA_SEL_4		(0x1)
#define  CMS_PGA_SEL_8		(0x2)
#define  CMS_PGA_SEL_16		(0x3)
#define  CMS_PGA_SEL_32		(0x4)
#define  CMS_PGA_SEL_64		(0x5)
#define  CMS_PGA_SEL_128	(0x6)
#define  CMS_PGA_SEL_256	(0x7)

/*------频率设置----------------------------------*/
#define  CMS_ADCFRE_328KHZ	(0x0)	
#define  CMS_ADCFRE_656KHZ	(0x1)

#define  CMS_ADCFRE_328KHZ_SPEED_2p5HZ		(0x7)	
#define  CMS_ADCFRE_328KHZ_SPEED_5HZ		(0x6)	
#define  CMS_ADCFRE_328KHZ_SPEED_10HZ		(0x5)	
#define  CMS_ADCFRE_328KHZ_SPEED_20HZ		(0x4)
#define  CMS_ADCFRE_328KHZ_SPEED_80HZ		(0x3)
#define  CMS_ADCFRE_328KHZ_SPEED_320HZ		(0x2)
#define  CMS_ADCFRE_328KHZ_SPEED_640HZ		(0x1)
#define  CMS_ADCFRE_328KHZ_SPEED_1281HZ		(0x0)

#define  CMS_ADCFRE_656KHZ_SPEED_5HZ		(0x7)	
#define  CMS_ADCFRE_656KHZ_SPEED_10HZ		(0x6)	
#define  CMS_ADCFRE_656KHZ_SPEED_20HZ		(0x5)	
#define  CMS_ADCFRE_656KHZ_SPEED_40HZ		(0x4)
#define  CMS_ADCFRE_656KHZ_SPEED_160HZ		(0x3)
#define  CMS_ADCFRE_656KHZ_SPEED_640HZ		(0x2)
#define  CMS_ADCFRE_656KHZ_SPEED_1281HZ		(0x1)
#define  CMS_ADCFRE_656KHZ_SPEED_2562HZ		(0x0)

/*------其他设置----------------------------------*/
#define  CMS_POWER_SEL_LOW	(0x1)		
#define  CMS_POWER_SEL_HIGH	(0x0)		

#define  CMS_CHOP_EN			(0x0)			
#define  CMS_CHOP_OFF			(0x1)	

#define  CMS_CHOP_ADC_FREDIV_16	(0x0)		
#define  CMS_CHOP_ADC_FREDIV_32	(0x1)		

#define  CMS_CHOP_FREDIV_4		(0x0)		
#define  CMS_CHOP_FREDIV_8		(0x1)		
#define  CMS_CHOP_FREDIV_16	(0x2)			
#define  CMS_CHOP_FREDIV_32	(0x3)			

#define	 CMS_DEAD_ZONE_MIN		(0x0)		//MIN
#define	 CMS_DEAD_ZONE_MAX		(0x1)		//MAX

/*------命令字节----------------------------------*/
#define  CMS_CMD_WRITE_CONFIG1	(0x65)	
#define  CMS_CMD_WRITE_CONFIG2	(0x69)	
#define  CMS_CMD_WRITE_CONFIG3	(0x6D)	
#define  CMS_CMD_WRITE_CONFIG4  (0x61)	

#define  CMS_CMD_READ_CONFIG1	(0x56)	
#define  CMS_CMD_READ_CONFIG2	(0x5A)	
#define  CMS_CMD_READ_CONFIG3	(0x5E)	
#define  CMS_CMD_READ_CONFIG4   (0x52)	
/*****************************************************************************/
/* Global variable declarations ('extern', definition in C source) */
/*****************************************************************************/

/*****************************************************************************/
/* Global function prototypes ('extern', definition in C source) */
/*****************************************************************************/
/******************************************************************************
 ** \brief	 SigmaDeltaADCInit
 **			 
 ** \param [in] none
 ** \return  none
 ** \note   
*****************************************************************************/
void SigmaDeltaADCInit(void);
/******************************************************************************
 ** \brief	 SigmaDeltaCheckReady
 **			  数据检测
 ** \param [in] delay：延时时间
 ** \return  0：检测到有效电平  1：延时时间内未检测到有效电平
 ** \note   
*****************************************************************************/
uint8_t SigmaDeltaCheckReady(uint16_t delay);
/******************************************************************************
 ** \brief	 SigmaDeltaWaitReady
 **			  数据检测(强制等待)
 ** \param [in] none
 ** \return none
 ** \note   
*****************************************************************************/
void SigmaDeltaWaitReady(void);
/******************************************************************************
 ** \brief	 SigmaDeltaAdcReadReg
 **			 配置读取
 ** \param [in] cmd : 命令字节
 ** \return  配置数据
 ** \note  
*****************************************************************************/
uint8_t SigmaDeltaAdcReadReg(uint8_t cmd);
/******************************************************************************
 ** \brief	 SigmaDeltaAdcReadData
 **			 读取ADC数据
 ** \param [in] none
 ** \return  24位ADC数据
 ** \note  
*****************************************************************************/
uint32_t SigmaDeltaAdcReadData(void);
/******************************************************************************
 ** \brief	 SigmaDeltaAdcWriteReg
 **			 写配置
 ** \param [in] cmd: 命令字节
**				dat: 数据
 ** \return  24位ADC数据
 ** \note  
*****************************************************************************/
uint32_t SigmaDeltaAdcWriteReg(uint8_t cmd, uint8_t dat);
/******************************************************************************
 ** \brief	 SigmaDeltaADCEnterSleep
 **			 进入低功耗模式
 ** \param [in] none
 ** \return  none
 ** \note   
*****************************************************************************/
void SigmaDeltaADCEnterSleep(void);

/******************************************************************************
 ** \brief	 SigmaDeltaADCWork
**			 正常工作模式
 ** \param [in] none
 ** \return  none
 ** \note   
*****************************************************************************/
void SigmaDeltaADCWork(void);

#endif /* __BSP_SIGMA_DELTA_ADC_H__ */








